@@ -62,6 +62,7 @@ sub _generate_accessor_any{
         # this setter
         $accessor .= 'return ' if !$is_weak && !$trigger && !$should_deref;
 
+        $accessor .= "my \@old_value = exists $slot ? $slot : ();\n" if $trigger;
         $accessor .= "$slot = $value;\n";
 
         if ($is_weak) {
@@ -69,7 +70,7 @@ sub _generate_accessor_any{
         }
 
         if ($trigger) {
-            $accessor .= '$trigger->('.$self.', '.$value.');' . "\n";
+            $accessor .= '$trigger->('.$self.', '.$value.', @old_value);' . "\n";
         }
 
         $accessor .= "}\n";
@@ -187,7 +188,7 @@ Mouse::Meta::Method::Accessor - A Mouse method generator for accessors
 
 =head1 VERSION
 
-This document describes Mouse version 1.06
+This document describes Mouse version 1.07
 
 =head1 SEE ALSO
 
